<?php
/* References
 * https://github.com/chipbennett/oenology/blob/master/functions/options.php#L84
 * http://www.chipbennett.net/2011/02/17/incorporating-the-settings-api-in-wordpress-themes/7/
 */
/* Add admin menu */
add_action( 'admin_menu', 'spp_lch_admin_menu' );
function spp_lch_admin_menu() {
	// Create options page
	add_submenu_page('edit.php?post_type=spp_lch_popups', 'Settings', 'Settings', 'manage_options', 'spp_lch_settings', 'spp_lch_options_page');
}

// Output the settings page
function spp_lch_options_page() {
	$tab = ( isset( $_GET['tab'] )  ? $_GET['tab'] : 'defaults' );
	$settings_section = 'spp_lch_settings_'.$tab.'_tab';
	?>
	<div class="wrap">
		<h2><?php echo SPP_LCH_PLUGIN_NAME; ?> Settings</h2>
		<?php settings_errors(  ); ?>
		<?php spp_lch_settings_page_tabs(); ?>

		<form action='options.php' method='post'>
			<?php 
			// Call functions to build form
			settings_fields( 'spp_lch_options' );
			//do_settings_sections( 'spp_lch_settings' );
			do_settings_sections( $settings_section );

			// Update settings based on tab			
			?>
			<p class="submit">
			<?php
			submit_button( 'Save Settings', 'primary', 'spp_lch_options[submit-'.$tab.']', false, array( 'id' => 'submit-'.$tab ) );
			submit_button( 'Reset', 'secondary', 'spp_lch_option[reset-'.$tab.']', false, array( 'id' => 'reset-'.$tab ) );
			?></p>
		</form>
	</div>
	<?php
}

// Create tabs
function spp_lch_get_settings_page_tabs() {
	$tabs = array(
		'defaults' => 'Defaults',
		'design' => 'Design'
		);
	return $tabs;
}

// HTML Markup for tabs
function spp_lch_settings_page_tabs( $current = 'defaults' ) {
	// Determind which tab to display
	if( isset( $_GET['tab'] ) ) :
		$current = $_GET['tab'];
	else:
		$current = 'defaults';
	endif;

	// Get list of tabs
	$tabs = spp_lch_get_settings_page_tabs();
	$links = array();

	// Create links for each tab
	foreach ($tabs as $tab => $name) :
		if( $tab == $current ) :
			$links[] = '<a class="nav-tab nav-tab-active" href="?post_type=spp_lch_popups&page=spp_lch_settings&tab='.$tab.'">'.$name.'</a>';
		else :
			$links[] = '<a class="nav-tab" href="?post_type=spp_lch_popups&page=spp_lch_settings&tab='.$tab.'">'.$name.'</a>';
		endif;
	endforeach;

	echo '<h2 class="nav-tab-wrapper">';
	foreach ( $links as $link ) {
		echo $link;
	}
	echo '</h2>';
}

// Register settings
add_action( 'admin_init', 'spp_lch_initialize_settings' );
function spp_lch_initialize_settings() {
	// Register fields
	register_setting( 
		'spp_lch_options',
		'spp_lch_options', 
		'spp_lch_validate_options' );

	// Add settings sections
	spp_lch_add_settings_sections();
	//add_settings_section( 'global', 'One Section', 'spp_lch_global_section_callback', 'spp_lch_settings' );

	// Add settings fields
	spp_lch_add_settings_fields();
	//add_settings_field( 'textfield', 'Text Field', 'spp_lch_textfield_field_callback', 'spp_lch_settings', 'global' );
}

/*---------------
 Sections
 ---------------*/
// Register multiple settings (called in admin_init)
function spp_lch_add_settings_sections() {
	// Array with settings identifiers
	$sects = array(
		'global' => array(
			'id' => 'global',
			'title' => 'Global Popups',
			'page' => 'spp_lch_settings_defaults_tab'
			),
		'design' => array(
			'id' => 'design',
			'title' => 'Global Design',
			'page' => 'spp_lch_settings_design_tab'
			)
		);

	// Loop through each
	foreach ($sects as $s) {
		add_settings_section( 
			$s['id'].'_section',
			$s['title'].' Options',
			'spp_lch_'.$s['id'].'_section_callback',
			$s['page']
			);
	}
}

/*----------------
Sections callback
-----------------*/
// Section callback
function spp_lch_global_section_callback() {
}
function spp_lch_design_section_callback() {
}

/*------------------
Fields
------------------*/
// Register multiple fields (called in admin_init)
function spp_lch_add_settings_fields () {
	global $spp_lch_options;

	// Array with field info
	$fields = array(
		'default_ad' => array(
			'id' => 'default_ad',
			'title' => 'Post default popup',
			'page' => 'spp_lch_settings_defaults_tab',
			'section' => 'global_section'
			),
		'page_lchpopup' => array(
			'id' => 'page_lchpopup',
			'title' => 'Page default popup',
			'page' => 'spp_lch_settings_defaults_tab',
			'section' => 'global_section'
			),
		'home_lchpopup' => array(
			'id' => 'home_lchpopup',
			'title' => 'Home page popup',
			'page' => 'spp_lch_settings_defaults_tab',
			'section' => 'global_section'
			),
		'archive_lchpopup' => array(
			'id' => 'archive_lchpopup',
			'title' => 'Archive popup',
			'page' => 'spp_lch_settings_defaults_tab',
			'section' => 'global_section'
			),
		'cookie' => array(
			'id' => 'cookie',
			'title' => 'Always show?',
			'page' => 'spp_lch_settings_defaults_tab',
			'section' => 'global_section'
			),
		'cookie_duration' => array(
			'id' => 'cookie_duration',
			'title' => 'Cookie duration',
			'page' => 'spp_lch_settings_defaults_tab',
			'section' => 'global_section'
			),
		'layoutdesign' => array(
			'id' => 'layoutdesign',
			'title' => 'Popup design',
			'page' => 'spp_lch_settings_design_tab',
			'section' => 'design_section'
			)
		);

	// Loop through each in array
	foreach ($fields as $f) {
		add_settings_field( 
			$f['id'],
			$f['title'],
			'spp_lch_'.$f['id'].'_field_callback',
			$f['page'],
			$f['section']
			);
	}
}

/*--------------------
Fields callback
--------------------*/
function spp_lch_default_ad_field_callback() {
	// Be sure the field names are formatted for array!
	// Also be sure name does not have ''
	global $spp_lch_options;
	
	$all_spp_lch_popups = get_posts('post_type=spp_lch_popups&showposts=-1&orderby=name&order=ASC');
	$default_lchpopup = $spp_lch_options['default_lchpopup'];
	?>
	<select name="spp_lch_options[default_lchpopup]">
		<option value="0">None</option>
	  <?php 
		foreach( $all_spp_lch_popups as $single_post ){
			?>
			<option value="<?php echo $single_post->ID; ?>" <?php selected( $default_lchpopup, $single_post->ID, true ); ?>><?php echo $single_post->post_title; ?></option>
			<?php
		}
	  ?>
	  </select>
	<?php
}
function spp_lch_page_lchpopup_field_callback() {
	global $spp_lch_options;
	$all_spp_lch_popups = get_posts('post_type=spp_lch_popups&showposts=-1&orderby=name&order=ASC');
	$page_lchpopup = $spp_lch_options['page_lchpopup'];
	?>
	<select name="spp_lch_options[page_lchpopup]">
		<option value="0">None</option>
	  <?php 
		foreach( $all_spp_lch_popups as $single_post ){
			?>
			<option value="<?php echo $single_post->ID; ?>" <?php selected( $page_lchpopup, $single_post->ID ); ?>><?php echo $single_post->post_title; ?></option>
			<?php
		}
	  ?>
	  </select>
	<?php
}
function spp_lch_home_lchpopup_field_callback() {
	global $spp_lch_options;
	$all_spp_lch_popups = get_posts('post_type=spp_lch_popups&showposts=-1&orderby=name&order=ASC');
	$home_lchpopup = $spp_lch_options['home_lchpopup'];
	?>
	<select name="spp_lch_options[home_lchpopup]" >
	  <option value="0">None</option>
	  <?php 
		foreach( $all_spp_lch_popups as $single_post ){
			?>
			<option value="<?php echo $single_post->ID; ?>" <?php selected( $home_lchpopup, $single_post->ID ); ?>><?php echo $single_post->post_title; ?></option>
			<?php
		}
	  ?>
	  </select>
	<?php
}
function spp_lch_archive_lchpopup_field_callback() {
	global $spp_lch_options;
	$all_spp_lch_popups = get_posts('post_type=spp_lch_popups&showposts=-1&orderby=name&order=ASC');
	$archive_lchpopup = $spp_lch_options['archive_lchpopup'];
	?>
	<select name="spp_lch_options[archive_lchpopup]" >
	  <option value="0" <?php selected( $archive_lchpopup, '0' ); ?>>None</option>
	  <?php 
		foreach( $all_spp_lch_popups as $single_post ){
			?>
			<option value="<?php echo $single_post->ID; ?>" <?php selected( $archive_lchpopup, $single_post->ID ); ?>><?php echo $single_post->post_title; ?></option>
			<?php		
		}
	  ?>
	  </select>
	<?php
}
function spp_lch_cookie_duration_field_callback() {
	global $spp_lch_options;
	?>
	<input type="text" name="spp_lch_options[cookie_duration]" class="small-text" id="cookie_duration" value="<?php echo sanitize_text_field( $spp_lch_options['cookie_duration'] ); ?>"> <label for="cookie_duration">Number of days to hide if "Hide is clicked"</label>
	<?php
}
function spp_lch_cookie_field_callback() {
	global $spp_lch_options;
	?>
	<input type="checkbox" name="spp_lch_options[cookie]" value="1" id="cookie" <?php checked( $spp_lch_options['cookie'], '1', true ); ?>> <label for="cookie">Cookie ignored. Use for testing only.</label>
	<?php
}
function spp_lch_layoutdesign_field_callback(){
	global $spp_lch_options;
	$frobs = sanitize_text_field( $spp_lch_options['frobs'] );
	$frobc = sanitize_text_field( $spp_lch_options['frobc'] );
	$frobstyle = $spp_lch_options['frobstyle'];
	$frobgc = sanitize_text_field( $spp_lch_options['frobgc'] );
	$frobgi = $spp_lch_options['frobgi'];
	$frobgp = sanitize_text_field( $spp_lch_options['frobgp'] );
	$fribs = sanitize_text_field( $spp_lch_options['fribs'] );
	$fribc = sanitize_text_field( $spp_lch_options['fribc'] );
	$fribstyle = $spp_lch_options['fribstyle'];
	$fribgc = sanitize_text_field( $spp_lch_options['fribgc'] );
	$fribgi = $spp_lch_options['fribgi'];
	$fribgp = sanitize_text_field( $spp_lch_options['fribgp'] );
	$fribgopacity = $spp_lch_options['fribgopacity'];
	$frtxtc = sanitize_text_field( $spp_lch_options['frtxtc'] );
	//print_r($spp_lch_options);
	?>
	<div class="frame-layout">
		<h5>Outer Border</h5>
		<div class="borderopts"><label>Size <input type="text" class="small-text" name="spp_lch_options[frobs]" value="<?php echo $frobs; ?>"></label></div>
		<div class="borderopts"><label>Color <input type="text" class="small-text color-picker" name="spp_lch_options[frobc]" value="<?php echo $frobc; ?>"></label></div>
		<div class="borderopts">
			<label>Style
			<select name="spp_lch_options[frobstyle]">
			<option value="0" <?php selected( $frobstyle, '0', true ); ?>>None</option>
			<option value="solid" <?php selected( $frobstyle, 'solid', true ); ?>>Solid</option>
			<option value="dotted" <?php selected( $frobstyle, 'dotted', true ); ?>>Dotted</option>
			<option value="dashed" <?php selected( $frobstyle, 'dashed', true ); ?>>Dashed</option>
			</select>
			</label>
		</div>
		<h5>Outer Background</h5>
		<div class="backgroundopts"><label>Color <input type="text" class="small-text color-picker" name="spp_lch_options[frobgc]" value="<?php echo $frobgc; ?>"></label></div>
		<div class="backgroundopts"><label>Image</label>
			<select id="frobgi" name="spp_lch_options[frobgi]">
				<option value="0" <?php selected( $frobgi, '0', true ); ?>>None</option>
				<option value="bokeh" <?php selected( $frobgi, 'bokeh', true ); ?>>Bokeh</option>
				<option value="flower" <?php selected( $frobgi, 'flower', true ); ?>>Flower</option>
				<option value="grass" <?php selected( $frobgi, 'grass', true ); ?>>Grass</option>
				<option value="log" <?php selected( $frobgi, 'log', true ); ?>>Log</option>
				<option value="paper" <?php selected( $frobgi, 'paper', true ); ?>>Paper</option>
				<option value="stone" <?php selected( $frobgi, 'stone', true ); ?>>Stone</option>
			</select>
		</div>
		<div class="backgroundopts"><img class="frobgi-preview" <?php if( !empty( $frobgi ) ) { ?>src="<?php echo SPP_LCH_DIR.'/modules/images/'.$frobgi.'_preview.jpg'; ?>"<?php } ?>></div>
		<div class="backgroundopts"><label>Padding <input type="text" class="small-text" name="spp_lch_options[frobgp]" value="<?php echo $frobgp; ?>"></label></div>
		<h5>Inner Border</h5>
		<div class="borderopts"><label>Size <input type="text" class="small-text" name="spp_lch_options[fribs]" value="<?php echo $fribs; ?>"></label></div>
		<div class="borderopts"><label>Color <input type="text" class="small-text color-picker" name="spp_lch_options[fribc]" value="<?php echo $fribc; ?>"></label></div>
		<div class="borderopts">
			<label>Style
			<select name="spp_lch_options[fribstyle]">
			<option value="0" <?php selected( $fribstyle, '0', true ); ?>>None</option>
			<option value="solid" <?php selected( $fribstyle, 'solid', true ); ?>>Solid</option>
			<option value="dotted" <?php selected( $fribstyle, 'dotted', true ); ?>>Dotted</option>
			<option value="dashed" <?php selected( $fribstyle, 'dashed', true ); ?>>Dashed</option>
			</select>
			</label>
		</div>
		<h5>Inner Background</h5>
		<div class="backgroundopts"><label>Color <input type="text" class="small-text color-picker" name="spp_lch_options[fribgc]" value="<?php echo $fribgc; ?>"></label></div>
		<div class="backgroundopts"><label>Image</label>
			<select id="fribgi" name="spp_lch_options[fribgi]">
				<option value="0" <?php selected( $fribgi, '0', true ); ?>>None</option>
				<option value="bokeh" <?php selected( $fribgi, 'bokeh', true ); ?>>Bokeh</option>
				<option value="flower" <?php selected( $fribgi, 'flower', true ); ?>>Flower</option>
				<option value="grass" <?php selected( $fribgi, 'grass', true ); ?>>Grass</option>
				<option value="log" <?php selected( $fribgi, 'log', true ); ?>>Log</option>
				<option value="paper" <?php selected( $fribgi, 'paper', true ); ?>>Paper</option>
				<option value="stone" <?php selected( $fribgi, 'stone', true ); ?>>Stone</option>
			</select>
		</div>
		<div class="backgroundopts"><img class="fribgi-preview" <?php if( !empty( $fribgi ) ) { ?>src="<?php echo SPP_LCH_DIR.'/modules/images/'.$fribgi.'_preview.jpg'; ?>"<?php } ?>></div>
		<div class="backgroundopts"><label>Padding <input type="text" class="small-text" name="spp_lch_options[fribgp]" value="<?php echo $fribgp; ?>"></label></div>
		<div class="backgroundopts"><label>Opaque <input type="checkbox" name="spp_lch_options[fribgopacity]" value="1" <?php checked( $fribgopacity, '1', true ); ?>></label></div>
		<h5>Text</h5>
		<div class="backgroundopts"><label>Color <input type="text" class="small-text color-picker" name="spp_lch_options[frtxtc]" value="<?php echo $frtxtc; ?>"></label></div>
	</div>
	<?php
}

// Validate options
function spp_lch_validate_options( $input ) {
	global $spp_lch_options;
	$valid_input = $spp_lch_options;

	// Determine which tab is submitted
	$defaults = ( !empty( $input['submit-defaults'] ) ? true : false );
	$framedesign = ( !empty( $input['submit-design'] ) ? true : false );

	if( $defaults ) {
		// validate only defaults settings
		$valid_input['default_lchpopup'] = ( isset( $input['default_lchpopup'] ) && is_numeric( $input['default_lchpopup'] ) ) ? $input['default_lchpopup'] : '' ;
		$valid_input['page_lchpopup'] = ( isset( $input['page_lchpopup'] ) && is_numeric( $input['page_lchpopup'] ) ) ? $input['page_lchpopup'] : '' ;
		$valid_input['home_lchpopup'] = ( isset( $input['home_lchpopup'] ) && is_numeric( $input['home_lchpopup'] ) ) ? $input['home_lchpopup'] : '' ;
		$valid_input['archive_lchpopup'] = ( isset( $input['archive_lchpopup'] ) && is_numeric( $input['archive_lchpopup'] ) ) ? $input['archive_lchpopup'] : '' ;		
		$valid_input['cookie'] = ( isset( $input['cookie'] ) && $input['cookie'] == 1 ) ? $input['cookie'] : '0' ;
		$valid_input['cookie_duration'] = ( isset( $input['cookie_duration'] ) && is_numeric( $input['cookie_duration'] ) ) ? $input['cookie_duration'] : '' ;

		// reuse design settings
		$valid_input['frobs'] = $spp_lch_options['frobs'];
		$valid_input['frobc'] = $spp_lch_options['frobc'];
		$valid_input['frobstyle'] = $spp_lch_options['frobstyle'];
		$valid_input['frobgc'] = $spp_lch_options['frobgc'];
		$valid_input['frobgi'] = $spp_lch_options['frobgi'];
		$valid_input['frobgp'] = $spp_lch_options['frobgp'];
		$valid_input['fribs'] = $spp_lch_options['fribs'];
		$valid_input['fribc'] = $spp_lch_options['fribc'];
		$valid_input['fribstyle'] = $spp_lch_options['fribstyle'];
		$valid_input['fribgc'] = $spp_lch_options['fribgc'];
		$valid_input['fribgi'] = $spp_lch_options['fribgi'];
		$valid_input['fribgp'] = $spp_lch_options['fribgp'];
		$valid_input['fribgopacity'] = $spp_lch_options['fribgopacity'];
		$valid_input['frtxtc'] = $spp_lch_options['frtxtc'];

	} elseif ( $framedesign ) {
		// reuse defaults settings
		$valid_input['default_lchpopup'] = $spp_lch_options['default_lchpopup'];
		$valid_input['page_lchpopup'] = $spp_lch_options['page_lchpopup'];
		$valid_input['home_lchpopup'] = $spp_lch_options['home_lchpopup'];
		$valid_input['archive_lchpopup'] = $spp_lch_options['archive_lchpopup'];
		$valid_input['cookie'] = $spp_lch_options['cookie'];
		$valid_input['cookie_duration'] = $spp_lch_options['cookie_duration'];

		// Allowed selection variables
		$allowed_style = array( 'solid', 'dotted', 'dashed' );
		$allowed_images = array( 'bokeh', 'flower', 'grass', 'log', 'paper', 'stone' );
		// validate only design settings
		$valid_input['frobs'] = ( isset( $input['frobs'] ) && is_numeric( $input['frobs'] ) ) ? $input['frobs'] : '' ;
		$valid_input['frobc'] = ( isset( $input['frobc'] ) && preg_match( '/^#[a-f0-9]{6}$/i', $input['frobc'] ) == '1' ) ? $input['frobc'] : '' ;
		$valid_input['frobstyle'] = ( isset( $input['frobstyle'] ) && in_array( $input['frobstyle'], $allowed_style ) ) ? $input['frobstyle'] : '' ;
		$valid_input['frobgc'] = ( isset( $input['frobgc'] ) && preg_match( '/^#[a-f0-9]{6}$/i', $input['frobgc'] ) == '1' ) ? $input['frobgc'] : '' ;
		$valid_input['frobgi'] = ( isset( $input['frobgi'] ) && in_array( $input['frobgi'], $allowed_images ) ) ? $input['frobgi'] : '0' ;
		$valid_input['frobgp'] = ( isset( $input['frobgp'] ) ) ? sanitize_text_field( $input['frobgp'] ) : '0' ;
		$valid_input['fribs'] = ( isset( $input['fribs'] ) && is_numeric( $input['fribs'] ) ) ? $input['fribs'] : '' ;
		$valid_input['fribc'] = ( isset( $input['fribc'] ) && preg_match( '/^#[a-f0-9]{6}$/i', $input['fribc'] ) == '1' ) ? $input['fribc'] : '' ;
		$valid_input['fribstyle'] = ( isset( $input['fribstyle'] ) && in_array( $input['fribstyle'], $allowed_style ) ) ? $input['fribstyle'] : '' ;
		$valid_input['fribgc'] = ( isset( $input['fribgc'] ) && preg_match( '/^#[a-f0-9]{6}$/i', $input['fribgc'] ) == '1' ) ? $input['fribgc'] : '' ;
		$valid_input['fribgi'] = ( isset( $input['fribgi'] ) && in_array( $input['fribgi'], $allowed_images ) ) ? $input['fribgi'] : '0' ;
		$valid_input['fribgp'] = ( isset( $input['fribgp'] ) ) ? sanitize_text_field( $input['fribgp'] ) : '0' ;
		$valid_input['fribgopacity'] = ( isset( $input['fribgopacity'] ) ) ? '1' : '' ;
		$valid_input['frtxtc'] = ( isset( $input['frtxtc'] ) && preg_match( '/^#[a-f0-9]{6}$/i', $input['frtxtc'] ) == '1' ) ? $input['frtxtc'] : '' ;

	}
	return $valid_input;
	
	/*print_r($valid_input);
	exit();*/
}
?>